/************************************************************************************ 
Data download  **********************************************************************
************************************************************************************/ 
libname sas 'C:\Users\Anastasios\Desktop\DISP';


%let wrds = wrds.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;

rsubmit;

%let endyear = 2017;

%macro getoptions;
	%do yearnum = 1996 %to &endyear;
	proc sql;
		create table options as
		select a.secid, a.date, a.exdate, a.cp_flag, a.strike_price/1000 as strike_price, a.volume, 
        a.exdate-a.date as cal_days, abs(b.close) as close, a.strike_price/(1000*abs(b.close)) as moneyness, b.shrout
		from optionm.opprcd&yearnum as a, optionm.secprd as b, optionm.securd as c
		where a.date=b.date
		and a.volume>0
		and c.index_flag='0'
		and a.secid=b.secid=c.secid 
		order by a.secid, a.date, a.exdate, a.strike_price;
	    proc download
        data=work.options
        out=sas.optionmetrics_data&yearnum; 
	%end;

%mend;
%getoptions;

endrsubmit;
signoff;


/************************************************************************************ 
Some data manipulation **************************************************************
************************************************************************************/ 

%let endyear = 2017;
%macro saveoptions;
%do yearnum = 1996 %to &endyear;

data work.temp;
set sas.optionmetrics_data&yearnum;
datef=date+0;
exdatef=exdate+0;
if cp_flag='C' then type=1;
else if cp_flag='P' then type=-1;
mcap=close*shrout;
run;

proc sql;
create table sas.data&yearnum._final as
select secid, datef, exdatef, type, strike_price, cal_days, volume, close, moneyness, mcap
from work.temp;
quit;


/************************************************************************************ 
Exporting data for further use in Matlab  *******************************************
************************************************************************************/

proc export data=sas.data&yearnum._final
outfile="C:\Users\Anastasios\Desktop\DISP\data&yearnum._final_matlab.csv"
dbms=csv
replace;
run; 

%end;

%mend;
%saveoptions;


